@@ -127,15 +127,17 @@ static struct {
 		{ "application/x-java-archive", TRUE },
 		{ "application/x-lhz", TRUE },
 		{ "application/x-lzop", TRUE },
-		{ "application/x-lzop-compressed-tar", TRUE },
 		{ "application/x-ms-wim", TRUE },
 		{ "application/x-rar", TRUE },
 		{ "application/x-rar-compressed", TRUE },
 		{ "application/x-rpm", TRUE },
 		{ "application/x-rzip", TRUE },
 		{ "application/x-stuffit", TRUE },
+		{ "application/x-tzo", TRUE },
 		{ "application/x-war", TRUE },
 		{ "application/x-zoo", TRUE },
+		{ "application/x-zstd-compressed-tar", TRUE },
+		{ "application/zstd", TRUE },
 		{ "multipart/x-zip", TRUE },
 		{ NULL, FALSE }
 };
