@@ -19,6 +19,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
@@ -30,7 +31,13 @@
 #include "fr-command-lha.h"
 
 
-G_DEFINE_TYPE (FrCommandLha, fr_command_lha, FR_TYPE_COMMAND)
+struct _FrCommandLha
+{
+	FrCommand  parent_instance;
+};
+
+
+G_DEFINE_TYPE (FrCommandLha, fr_command_lha, fr_command_get_type ())
 
 
 /* -- list -- */
