@@ -102,7 +102,6 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-lzma",                    ".lzma",     0 },
 	{ "application/x-lzma-compressed-tar",     ".tar.lzma", 0 },
 	{ "application/x-lzop",                    ".lzo",      0 },
-	{ "application/x-lzop-compressed-tar",     ".tar.lzo",  0 },
 	{ "application/x-ms-wim",                  ".wim",      0 },
 	{ "application/x-rar",                     ".rar",      0 },
 	{ "application/x-rpm",                     ".rpm",      0 },
@@ -110,13 +109,16 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-rzip-compressed-tar",     ".tar.rz",   0 },
 	{ "application/x-tar",                     ".tar",      0 },
 	{ "application/x-tarz",                    ".tar.Z",    0 },
+	{ "application/x-tzo",                     ".tar.lzo",  0 },
 	{ "application/x-stuffit",                 ".sit",      0 },
 	{ "application/x-war",                     ".war",      0 },
 	{ "application/x-xar",                     ".xar",      0 },
 	{ "application/x-xz",                      ".xz",       0 },
 	{ "application/x-xz-compressed-tar",       ".tar.xz",   0 },
 	{ "application/x-zoo",                     ".zoo",      0 },
+	{ "application/x-zstd-compressed-tar",     ".tar.zst",  0 },
 	{ "application/zip",                       ".zip",      0 },
+	{ "application/zstd",                      ".zst",      0 },
 	{ NULL, NULL, 0 }
 };
 
@@ -167,11 +169,12 @@ FrExtensionType file_ext_type[] = {
 	{ ".tar.lz", "application/x-lzip-compressed-tar" },
 	{ ".tar.lz4", "application/x-lz4-compressed-tar" },
 	{ ".tar.lzma", "application/x-lzma-compressed-tar" },
-	{ ".tar.lzo", "application/x-lzop-compressed-tar" },
+	{ ".tar.lzo", "application/x-tzo" },
 	{ ".tar.7z", "application/x-7z-compressed-tar" },
 	{ ".tar.rz", "application/x-rzip-compressed-tar" },
 	{ ".tar.xz", "application/x-xz-compressed-tar" },
 	{ ".tar.Z", "application/x-tarz" },
+	{ ".tar.zst", "application/x-zstd-compressed-tar" },
 	{ ".taz", "application/x-tarz" },
 	{ ".tbz", "application/x-bzip-compressed-tar" },
 	{ ".tbz2", "application/x-bzip-compressed-tar" },
@@ -180,7 +183,8 @@ FrExtensionType file_ext_type[] = {
 	{ ".tlz", "application/x-lzip-compressed-tar" },
 	{ ".tlz4", "application/x-lz4-compressed-tar" },
 	{ ".tzma", "application/x-lzma-compressed-tar" },
-	{ ".tzo", "application/x-lzop-compressed-tar" },
+	{ ".tzo", "application/x-tzo" },
+	{ ".tzst", "application/x-zstd-compressed-tar" },
 	{ ".war", "application/x-war" },
 	{ ".wim", "application/x-ms-wim" },
 	{ ".xar", "application/x-xar" },
@@ -189,6 +193,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".Z", "application/x-compress" },
 	{ ".zip", "application/zip" },
 	{ ".zoo", "application/x-zoo" },
+	{ ".zst", "application/zstd" },
 	{ NULL, NULL }
 };
 
